zlib: Data compression library
==============================

Description
-----------

Massively Spiffy Yet Delicately Unobtrusive Compression Library (Also
Free, Not to Mention Unencumbered by Patents)

License
-------

-  Modified BSD.


Upstream Contact
----------------

-  http://www.zlib.net/
